==> 01.98.zip: tweet_live-01.98/web/humanitats-digital/config.php <==
<?php
$config = array(
   	'hashtag'    => '#digihum',
   	'date'   => '09.11.2011',
   	'heure'   => '10h00-20h00',
   	'place'   => 'Espai: Mirador CCCB - Barcelona',

   	'title' => "Humanitats Digitals",
   	'abstract'   => "<b><a href='http://www.cccb.org/ca/curs_o_conferencia-i_c_i_6_humanitats_digitals-39541' target='_blank'>Humanitats Digitals</a></b><br/> 09/11/2011, 10:00-14:00 - 18:00-20:00<br/>@ Espai: Mirador CCCB - Barcelona - entrada gratuïta",
   	'description'=> "La era de las nuevas tecnologías de la información y el conocimiento está provocando una transformación de las ciencias humanas clásicas. Una nueva era de estudio surgida de la intersección entre las herramientas digitales y las humanidades promueve la interacción de los adelantos de la tecnocultura con la filosofía, la literatura, el arte, la lingüística y los estudios culturales. Los trabajos realizados por el <a href='http://www.iri.centrepompidou.fr/' target='_blank'>Institut de Recherche et Innovation du Centre Pompidou (IRI)</a> están centrados en este nuevo campo conocido como <b><a href='http://www.cccb.org/lab/es/ici/estudis-digitals/#more-1435' target='_blank'>Humanidades digitales</a></b>, en las que adopta especial importancia la condición participativa activada por la web 2.0 (web social) así como por la emergencia de la web 3.0 (web semántica).",
   	'link' => 'http://www.cccb.org/ca/curs_o_conferencia-i_c_i_6_humanitats_digitals-39541',
   	'islive'     => false,
   	'islive_embed' => "<object width='501' height='376' classid='clsid:d27cdb6e-ae6d-11cf-96b8-444553540000'>
<param name='flashvars' value='cid=9689562&amp;autoplay=false'/>
<param name='allowfullscreen' value='true'/>
<param name='allowscriptaccess' value='always'/>
<param name='src' value='http://www.ustream.tv/flash/viewer.swf'/>
<embed flashvars='cid=9689562&amp;autoplay=false' width='501' height='376' allowfullscreen='true' allowscriptaccess='always' src='http://www.ustream.tv/flash/viewer.swf' type='application/x-shockwave-flash'></embed>
</object>",
   	'keywords'   => 'humanitats digitals, iri, cccb',
   	'rep' => basename('__DIR__'),
   	'partenaires'=> "<a href='http://www.cccb.org' class='footerLink' target='_blank'>CCCB</a> | <a href='http://www.iri.centrepompidou.fr/' class='footerLink' target='_blank'>IRI</a>",

    'client_visual' => 'images/big_visuel_humanitats.png',// 501 × 376 pixels
    
 	'head_logo' => 'images/head_logo_cccb.gif', // 171 × 63 pixels
 	
  	'slide_background' => 'images/slide4-humanitats.png', // 606 × 282 pixels
    
  	'archive_img' => 'images/archive-humanitats.png', // 270 × 150 pixels

 	'archive_title' => "Humanitats Digitals #06",
 	'archive_description' => 'par <a href="http://www.cccb.org" target="_blank">CCCB</a> et l\'<a href="http://www.iri.centrepompidou.fr" target="_blank">IRI</a><br/>Espai: Mirador CCCB - Barcelona - 9 novembre 2011 10:00-14:00 - 18:00-20:00',

    // After the event
	'metadata'    => "http://ldt.iri.centrepompidou.fr/ldtplatform/ldt/cljson/id/67280b1c-ff30-11e0-a82d-00145ea49a02",
	'duration'   => 23705500,
	'player'        => "res/metadataplayer/src/js/LdtPlayer.js",
	'div_height'    => 740,
	'player_width'  => 650,
	'player_height' => 600,
);

==> V01.99.zip: tweet_live-V01.99/web/humanitats-digital/config.php <==
<?php
$config = array(
   	'hashtag'    => '#digihum',
   	'date'   => '09.11.2011',
   	'heure'   => '10h00-20h00',
   	'place'   => 'Espai: Mirador CCCB - Barcelona',

   	'title' => "Humanitats Digitals",
   	'abstract'   => "<b><a href='http://www.cccb.org/ca/curs_o_conferencia-i_c_i_6_humanitats_digitals-39541' target='_blank'>Humanitats Digitals</a></b><br/> 09/11/2011, 10:00-14:00 - 18:00-20:00<br/>@ Espai: Mirador CCCB - Barcelona - entrada gratuïta",
   	'description'=> "La era de las nuevas tecnologías de la información y el conocimiento está provocando una transformación de las ciencias humanas clásicas. Una nueva era de estudio surgida de la intersección entre las herramientas digitales y las humanidades promueve la interacción de los adelantos de la tecnocultura con la filosofía, la literatura, el arte, la lingüística y los estudios culturales. Los trabajos realizados por el <a href='http://www.iri.centrepompidou.fr/' target='_blank'>Institut de Recherche et Innovation du Centre Pompidou (IRI)</a> están centrados en este nuevo campo conocido como <b><a href='http://www.cccb.org/lab/es/ici/estudis-digitals/#more-1435' target='_blank'>Humanidades digitales</a></b>, en las que adopta especial importancia la condición participativa activada por la web 2.0 (web social) así como por la emergencia de la web 3.0 (web semántica).",
   	'link' => 'http://www.cccb.org/ca/curs_o_conferencia-i_c_i_6_humanitats_digitals-39541',
   	'islive'     => false,
   	'islive_embed' => "<object width='501' height='376' classid='clsid:d27cdb6e-ae6d-11cf-96b8-444553540000'>
<param name='flashvars' value='cid=9689562&amp;autoplay=false'/>
<param name='allowfullscreen' value='true'/>
<param name='allowscriptaccess' value='always'/>
<param name='src' value='http://www.ustream.tv/flash/viewer.swf'/>
<embed flashvars='cid=9689562&amp;autoplay=false' width='501' height='376' allowfullscreen='true' allowscriptaccess='always' src='http://www.ustream.tv/flash/viewer.swf' type='application/x-shockwave-flash'></embed>
</object>",
   	'keywords'   => 'humanitats digitals, iri, cccb',
   	'rep' => basename('__DIR__'),
   	'partenaires'=> "<a href='http://www.cccb.org' class='footerLink' target='_blank'>CCCB</a> | <a href='http://www.iri.centrepompidou.fr/' class='footerLink' target='_blank'>IRI</a>",

    'client_visual' => 'images/big_visuel_humanitats.png',// 501 × 376 pixels
    
 	'head_logo' => 'images/head_logo_cccb.gif', // 171 × 63 pixels
 	
  	'slide_background' => 'images/slide4-humanitats.png', // 606 × 282 pixels
    
  	'archive_img' => 'images/archive-humanitats.png', // 270 × 150 pixels

 	'archive_title' => "Humanitats Digitals #06",
 	'archive_description' => 'par <a href="http://www.cccb.org" target="_blank">CCCB</a> et l\'<a href="http://www.iri.centrepompidou.fr" target="_blank">IRI</a><br/>Espai: Mirador CCCB - Barcelona - 9 novembre 2011 10:00-14:00 - 18:00-20:00',

    // After the event
	'metadata'    => "67280b1c-ff30-11e0-a82d-00145ea49a02",
	'duration'   => 23705500,
	'player'        => "res/metadataplayer/src/js/LdtPlayer.js",
	'div_height'    => 740,
	'player_width'  => 650,
	'player_height' => 600,
);
